@@ -45,10 +45,10 @@ $sysdeps = {
     'cups-lpc'   => '/usr/local/sbin/lpc',
     'cups-lp'    => '/usr/local/bin/lp',
     'cups-cancel' => '/usr/local/bin/cancel',
-    'cups-enable' => '/usr/local/bin/enable',
-    'cups-disable' => '/usr/local/bin/disable',
-    'cups-accept' => '/usr/local/sbin/accept',
-    'cups-reject' => '/usr/local/sbin/reject',
+    'cups-enable' => '/usr/local/sbin/cupsenable',
+    'cups-disable' => '/usr/local/sbin/cupsdisable',
+    'cups-accept' => '/usr/local/sbin/cupsaccept',
+    'cups-reject' => '/usr/local/sbin/cupsreject',
     'cups-lpmove' => '/usr/local/sbin/lpmove',
     'cups-lpoptions' => '/usr/local/bin/lpoptions',
     'cups-lpinfo' => '/usr/local/sbin/lpinfo',
